@@ -66,7 +66,7 @@ class ImageDataset:
         check_for_corrupt_images: bool = True,
         preserve_file_path: bool = False,
     ):
-        """Intilize an ImageDataset from a ImageFolder style dataset."""
+        """Initialize an ImageDataset from a ImageFolder style dataset."""
         data_files = {}
         if train_dir:
             train_files = directory / Path(train_dir)
